@@ -29,8 +29,8 @@ from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-from google.api_core import operation
-from google.api_core import operation_async
+from google.api_core import operation  # type: ignore
+from google.api_core import operation_async  # type: ignore
 from google.cloud.redis_v1.services.cloud_redis import pagers
 from google.cloud.redis_v1.types import cloud_redis
 from google.protobuf import empty_pb2 as empty  # type: ignore
@@ -74,9 +74,41 @@ class CloudRedisAsyncClient:
     instance_path = staticmethod(CloudRedisClient.instance_path)
     parse_instance_path = staticmethod(CloudRedisClient.parse_instance_path)
 
+    common_billing_account_path = staticmethod(
+        CloudRedisClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        CloudRedisClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(CloudRedisClient.common_folder_path)
+    parse_common_folder_path = staticmethod(CloudRedisClient.parse_common_folder_path)
+
+    common_organization_path = staticmethod(CloudRedisClient.common_organization_path)
+    parse_common_organization_path = staticmethod(
+        CloudRedisClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(CloudRedisClient.common_project_path)
+    parse_common_project_path = staticmethod(CloudRedisClient.parse_common_project_path)
+
+    common_location_path = staticmethod(CloudRedisClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        CloudRedisClient.parse_common_location_path
+    )
+
     from_service_account_file = CloudRedisClient.from_service_account_file
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> CloudRedisTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            CloudRedisTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(CloudRedisClient).get_transport_class, type(CloudRedisClient)
     )
@@ -180,7 +212,8 @@ class CloudRedisAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and builtins.any([parent]):
+        has_flattened_params = builtins.any([parent])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -256,7 +289,8 @@ class CloudRedisAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and builtins.any([name]):
+        has_flattened_params = builtins.any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -365,7 +399,8 @@ class CloudRedisAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and builtins.any([parent, instance_id, instance]):
+        has_flattened_params = builtins.any([parent, instance_id, instance])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -470,7 +505,8 @@ class CloudRedisAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and builtins.any([update_mask, instance]):
+        has_flattened_params = builtins.any([update_mask, instance])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -565,7 +601,8 @@ class CloudRedisAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and builtins.any([name, redis_version]):
+        has_flattened_params = builtins.any([name, redis_version])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -665,7 +702,8 @@ class CloudRedisAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and builtins.any([name, input_config]):
+        has_flattened_params = builtins.any([name, input_config])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -761,7 +799,8 @@ class CloudRedisAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and builtins.any([name, output_config]):
+        has_flattened_params = builtins.any([name, output_config])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -856,7 +895,8 @@ class CloudRedisAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and builtins.any([name, data_protection_mode]):
+        has_flattened_params = builtins.any([name, data_protection_mode])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -954,7 +994,8 @@ class CloudRedisAsyncClient:
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and builtins.any([name]):
+        has_flattened_params = builtins.any([name])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
